==> weather-5.x-1.1.tar.gz: weather/helper.js <==
/*
 * Copyright (C) 2006 Tobias Toedter <t.toedter@gmx.net>
 *
 * This file is part of the Drupal Weather module.
 *
 * Weather is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Weather is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Weather; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */



function setup_place_list(http_request) {
  try {
    if (http_request.readyState == 4 && http_request.status == 200) {
      // This is an evil hack, but I just cannot
      // get Javascript to parse the XML ...
      // Comments welcome.
      var selection = document.forms["weather-custom-block-form"].elements["edit-icao"];
      var xml = http_request.responseText;
      var position = xml.indexOf('icao="');
      var places_icao = new Array();
      var places_name = new Array();
      var idx, option;

      while (position != -1) {
        // also skip the part 'icao="'
        xml = xml.substr(position + 6);
        // get the ICAO code
        places_icao.push(xml.substring(0, 4));
        // get the name without the closing tag
        places_name.push(xml.substring(6, xml.indexOf('</place>')));
        position = xml.indexOf('icao="');
      }

      // delete the current list of options, except the "- none -" entry
      selection.length = 1;

      // generate a new selection list
      for (idx = 0; idx < places_icao.length; idx++) {
        option = new Option(places_name[idx]);
        option.value = places_icao[idx];
        selection.options[selection.length] = option;
      }
        
      update_icao();
    }
  } catch (e) {}
}



function update_place(url) {
  var http_request = false;
  var new_country = document.forms["weather-custom-block-form"].elements["edit-country"].value;

  if (window.XMLHttpRequest) { // Mozilla, Safari, ...
    http_request = new XMLHttpRequest();
    if (http_request.overrideMimeType) {
      http_request.overrideMimeType('text/xml');
    }
  } else if (window.ActiveXObject) { // IE
    try {
      http_request = new ActiveXObject("Msxml2.XMLHTTP");
    } catch (e) {
      try {
        http_request = new ActiveXObject("Microsoft.XMLHTTP");
      } catch (e) {}
    }
  }

  if (!http_request) {
    // Cannot create an XMLHTTP instance
    return false;
  }
  
  http_request.onreadystatechange = function() { setup_place_list(http_request); };
  http_request.open('GET', url + "/places.php?country=" + escape(new_country), true);
  http_request.send(null);
}



function update_icao() {
  var new_icao = document.forms["weather-custom-block-form"].elements["edit-icao"].value;
  var i = document.forms["weather-custom-block-form"].elements["edit-icao"].selectedIndex;
  var new_name = document.forms["weather-custom-block-form"].elements["edit-icao"].options[i].text;
  if (new_icao == "- none -") {
    new_name = '';
  }
  document.forms["weather-custom-block-form"].elements["edit-real-name"].value = new_name;
}

==> weather-5.x-2.0.tar.gz: weather/helper.js <==
/*
 * Copyright (C) 2006-2007 Tobias Toedter <t.toedter@gmx.net>
 *
 * This file is part of the Drupal Weather module.
 *
 * Weather is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Weather is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Weather; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */



/* If JavaScript is enabled, use the AJAX version of the country
 * and place lookup. Otherwise, the ICAO textfield will be shown
 * without the country and place selection boxes.
 */
if (Drupal.jsEnabled) {
  $(function () {
    $('div#weather-js-show-selectbox').show();

    // update the ICAO and realname textfields after the place has changed
    $('#edit-place').change(function() {
      $('#edit-icao').val(this.options[this.selectedIndex].value);
      $('#edit-real-name').val(this.options[this.selectedIndex].text);
    });
  });
}



function setup_place_list(http_request) {
  try {
    if (http_request.readyState == 4 && http_request.status == 200) {
      // This is an evil hack, but I just cannot
      // get Javascript to parse the XML ...
      // Comments welcome.
      var selection = document.forms["weather-custom-block-form"].elements["edit-place"];
      var xml = http_request.responseText;
      var position = xml.indexOf('icao="');
      var places_icao = new Array();
      var places_name = new Array();
      var idx, option;

      while (position != -1) {
        // also skip the part 'icao="'
        xml = xml.substr(position + 6);
        // get the ICAO code
        places_icao.push(xml.substring(0, 4));
        // get the name without the closing tag
        places_name.push(xml.substring(6, xml.indexOf('</place>')));
        position = xml.indexOf('icao="');
      }

      // delete the current list of options
      selection.length = 0;

      // generate a new selection list
      for (idx = 0; idx < places_icao.length; idx++) {
        option = new Option(places_name[idx]);
        option.value = places_icao[idx];
        selection.options[selection.length] = option;
      }
        
      update_icao();
    }
  } catch (e) {}
}



function update_place(url) {
  var http_request = false;
  var new_country = document.forms["weather-custom-block-form"].elements["edit-country"].value;

  if (window.XMLHttpRequest) { // Mozilla, Safari, ...
    http_request = new XMLHttpRequest();
    if (http_request.overrideMimeType) {
      http_request.overrideMimeType('text/xml');
    }
  } else if (window.ActiveXObject) { // IE
    try {
      http_request = new ActiveXObject("Msxml2.XMLHTTP");
    } catch (e) {
      try {
        http_request = new ActiveXObject("Microsoft.XMLHTTP");
      } catch (e) {}
    }
  }

  if (!http_request) {
    // Cannot create an XMLHTTP instance
    return false;
  }
  
  http_request.onreadystatechange = function() { setup_place_list(http_request); };
  http_request.open('GET', url + "/places.php?country=" + escape(new_country), true);
  http_request.send(null);
}
